@@ -1,6 +1,9 @@
 import blazer
-from blazer.hpc.mpi import parallel, pipeline, partial as p
-from .funcs import calc_more_stuff, calc_some, calc_stuff, add_date
+from blazer.hpc.mpi import parallel
+from blazer.hpc.mpi import partial as p
+
+from .funcs import calc_stuff
+
 
 def test_parallel():
     with blazer.begin():
@@ -9,9 +12,9 @@ def test_parallel():
             p(calc_stuff, 2),
             p(calc_stuff, 3),
             p(calc_stuff, 4),
-            p(calc_stuff, 5)
+            p(calc_stuff, 5),
         ]
         result = parallel(tasks)
-        
+
         if blazer.ROOT:
             assert len(result) == len(tasks)
